"""Script for running tsunami inundation scenario for Dampier, WA, Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project.py
The output sww file is stored in project.output_time_dir 

The scenario is defined by a triangular mesh created from project.polygon,
the elevation data and a simulated submarine landslide.

Ole Nielsen and Duncan Gray, GA - 2005 and Jane Sexton, Nick Bartzis, GA - 2006
"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules
from os import sep
from os.path import dirname, basename
from os import mkdir, access, F_OK
from shutil import copy
import time
import sys


# Related major packages
from anuga.shallow_water import Domain
from anuga.shallow_water import Dirichlet_boundary
from anuga.shallow_water import File_boundary
from anuga.shallow_water import Reflective_boundary
from anuga.shallow_water.data_manager import convert_dem_from_ascii2netcdf, dem2pts
from anuga.pmesh.mesh_interface import create_mesh_from_regions
from anuga.geospatial_data.geospatial_data import *
from anuga.abstract_2d_finite_volumes.util import start_screen_catcher, copy_code_files

# Application specific imports
import project   # Definition of file names and polygons

#------------------------------------------------------------------------------
# Copy scripts to time stamped output directory and capture screen
# output to file
#------------------------------------------------------------------------------
copy_code_files(project.output_build_time_dir,__file__, 
               dirname(project.__file__)+sep+ project.__name__+'.py' )

start_screen_catcher(project.output_build_time_dir)

print 'USER:    ', project.user

#-------------------------------------------------------------------------------
# Preparation of topographic data
#
# Convert ASC 2 DEM 2 PTS using source data and store result in source data
# Do for coarse and fine data
# Fine pts file to be clipped to area of interest
#-------------------------------------------------------------------------------
print"project.combined_dir_name",project.combined_dir_name

# topography directory filenames
onshore_in_dir_name = project.onshore_in_dir_name
coast_in_dir_name = project.coast_in_dir_name
offshore_in_dir_name = project.offshore_in_dir_name
offshore1_in_dir_name = project.offshore1_in_dir_name
offshore2_in_dir_name = project.offshore2_in_dir_name

onshore_dir_name = project.onshore_dir_name
coast_dir_name = project.coast_dir_name
offshore_dir_name = project.offshore_dir_name
offshore1_dir_name = project.offshore1_dir_name
offshore2_dir_name = project.offshore2_dir_name
'''
# creates DEM from asc data
print "creates DEMs from asc data"
convert_dem_from_ascii2netcdf(onshore_in_dir_name,
                              basename_out=onshore_dir_name,
                              use_cache=True, verbose=True)

convert_dem_from_ascii2netcdf(offshore1_in_dir_name,
                              basename_out=offshore1_dir_name,
                              use_cache=True, verbose=True)
convert_dem_from_ascii2netcdf(offshore2_in_dir_name,
                              basename_out=offshore2_dir_name,
                              use_cache=True, verbose=True)

#creates pts file for onshore DEM
print "creates pts file for onshore DEM"
dem2pts(onshore_dir_name, use_cache=True, verbose=True)

#creates pts file for clipped DEMs
dem2pts(offshore1_dir_name,
        basename_out=offshore1_dir_name,
        use_cache=True, verbose=True)
dem2pts(offshore2_dir_name,
        basename_out=offshore2_dir_name,
        use_cache=True, verbose=True)

print'create Geospatial onshore objects from topographies'
#print'create Geospatial coastal objects from topographies'
#print'create Geospatial nickel bay objects from topographies'
#print'create Geospatial clipped TIN offshore objects from topographies'
#print'create Geospatial offshore objects from topographies'
G = Geospatial_data(file_name = onshore_dir_name + '.pts') +\
    Geospatial_data(file_name = coast_in_dir_name + '.txt') +\
    Geospatial_data(file_name = offshore_in_dir_name + '.txt') +\
    Geospatial_data(file_name = offshore1_dir_name + '.pts') +\
    Geospatial_data(file_name = offshore2_dir_name + '.pts')
     

print'add all geospatial objects'
#G = G1 + G2 + G3 + G4 + G_off

print'clip combined geospatial object by bounding polygon'
G_clipped = G.clip(project.poly_all)
#FIXME: add a clip function to pts
#print'shape of clipped data', G_clipped.get_data_points().shape

print'export combined DEM file'
if access(project.topographies_dir,F_OK) == 0:
    mkdir (project.topographies_dir)
G_clipped.export_points_file(project.combined_dir_name + '.pts')
#G_clipped.export_points_file(project.combined_dir_name + '.txt')

print'split combined data set'
G_small, G_other = G_clipped.split(0.1, True)

print'export split DEM file'
G_small.export_points_file(project.combined_dir_name + '_small' + '.pts')
G_other.export_points_file(project.combined_dir_name + '_other' + '.pts')
'''
print 'start reading:',project.combined_dir_name + '.pts'
G = Geospatial_data(file_name = project.combined_dir_name + '.pts')
print 'start export',project.combined_dir_name + '.txt'
G.export_points_file(project.combined_dir_name + '.txt')





